Deletes expired render files and their job records.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sweep(
{DateTime? now, bool dryRun}) → Future< RetentionReport> -
Deletes everything whose expiry is at or before
now(default: the current time).dryRunreports what would be deleted without deleting. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited