sweep abstract method
Deletes everything whose expiry is at or before now (default: the
current time). dryRun reports what would be deleted without deleting.
Implementation
Future<RetentionReport> sweep({DateTime? now, bool dryRun});
Deletes everything whose expiry is at or before now (default: the
current time). dryRun reports what would be deleted without deleting.
Future<RetentionReport> sweep({DateTime? now, bool dryRun});