renderProject property
The Flutter project the capture harness runs in, or null to auto-discover.
Implementation
final String? renderProject;
The Flutter project the capture harness runs in, or null to auto-discover.
final String? renderProject;